@@ -13,38 +13,6 @@ solve_qp <- function(basis_matrix, y, a_mat, b_vec, meq = 0) {
     return(quadprog::solve.QP(Dmat = d_mat, dvec = d_vec, Amat = t(a_mat), bvec = b_vec, meq = meq)$solution)
 }
 
-# Helper based on `osqp` for testing the `Solver` class.
-solve_osqp <- function(basis_matrix, y, lower, upper) {
-    # Set settings.
-    settings <- osqp::osqpSettings(
-        verbose = FALSE,
-        eps_abs = 1e-10,
-        eps_rel = 1e-10,
-        linsys_solver = 0L,
-        warm_start = FALSE
-    )
-
-    # Create matrices for `osqp`.
-    p_mat <- crossprod(basis_matrix, basis_matrix)
-    q_vec <- -crossprod(basis_matrix, y)
-
-    # Create constraint matrix.
-    a_mat <- diag(1, ncol(basis_matrix))
-
-    # Create model.
-    model <- osqp::osqp(
-        P = p_mat,
-        q = q_vec,
-        A = a_mat,
-        l = lower,
-        u = upper,
-        pars = settings
-    )
-
-    # Optimize.
-    return(model$Solve()$x)
-}
-
 # Compute performance measures.
 compute_measure <- function(true_parameters, estimated_parameters, measure) {
     # Extract the true and estimated parameters from the weights matrices.
@@ -108,25 +76,6 @@ StepThreeTester <- R6::R6Class("StepThreeTester",
     )
 )
 
-# Helper for testing private methods of `Backend` class.
-BackendTester <- R6::R6Class("BackendTester",
-    inherit = Backend,
-
-    public = list(
-        # Mock the number of cores detected during instantiation.
-        mock_machine_available_cores = function(cores) {
-            # Predetermine the number of cores on the machine.
-            private$.available_cores <- cores
-        },
-
-        # Expose the private method for testing.
-        set_cores = function(cores) {
-            # Set the cores.
-            private$.set_cores(cores)
-        }
-    )
-)
-
 # Helper for testing private methods of `Range` class.
 RangeTester <- R6::R6Class("RangeTester",
     inherit = Range,
